[ekiga] Add call back test (520 ekiga net) to local roster



commit 8151c7d708733fa47555af984cd5a1b2feb6f964
Author: Dominik Kopp <suse kabelfunk de>
Date:   Wed Sep 2 00:06:52 2009 +0200

    Add call back test (520 ekiga net) to local roster

 lib/engine/components/local-roster/local-heap.cpp |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)
---
diff --git a/lib/engine/components/local-roster/local-heap.cpp b/lib/engine/components/local-roster/local-heap.cpp
index 14bcee6..6979b3d 100644
--- a/lib/engine/components/local-roster/local-heap.cpp
+++ b/lib/engine/components/local-roster/local-heap.cpp
@@ -87,12 +87,13 @@ Local::Heap::Heap (Ekiga::ServiceCore &_core): core (_core), doc ()
     xmlDocSetRootElement (doc.get (), root);
 
     {
       // add 500 and 501 at ekiga.net in this case!
       std::set<std::string> groups;
 
       groups.insert (_("Services"));
       add (_("Echo test"), "sip:500 ekiga net", groups);
       add (_("Conference room"), "sip:501 ekiga net", groups);
+      add (_("Call back test"), "sip:520 ekiga net", groups);
     }
   }
 }
@@ -87,12 +87,13 @@ Local::Heap::Heap (Ekiga::ServiceCore &_core): core (_core), doc ()
 
     {
-      // add 500 and 501 at ekiga.net in this case!
+      // add 500, 501 and 520 at ekiga.net in this case!
       std::set<std::string> groups;
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]